Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CombineSentences ¶
CombineSentences will take the output from the SplitSentences func and combine it back into a single string using the passed delimiter. This may be used as a preparation step for writing the sentences all back into a single output file.
func SplitSentences ¶
SplitSentences will use the neurosnap/sentences tokenizer to split the content up into a slice of strings. Each string is a sentence, based on existing punctuation. This util method is hardcoded to english at the moment but the sentence splitter does support multiple languages which can be enabled later.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.